==> igniteui-react-core-18.2.0-beta.2.tgz: package/esm2015/lib/TimeAxisBreakDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { TimeAxisBreakDescription } from "./TimeAxisBreakDescription";
/**
 * @hidden
 */
export let TimeAxisBreakDescriptionMetadata = /*@__PURE__*/ (() => {
    class TimeAxisBreakDescriptionMetadata extends Base {
        static b(a) {
            if (TimeAxisBreakDescriptionMetadata.a == null) {
                TimeAxisBreakDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                TimeAxisBreakDescriptionMetadata.c(TimeAxisBreakDescriptionMetadata.a);
            }
            if (a.k(TimeAxisBreakDescriptionMetadata.a)) {
                return;
            }
            a.ab(TimeAxisBreakDescriptionMetadata.a);
        }
        static c(a) {
            a.item("Start", "Date");
            a.item("End", "Date");
            a.item("Interval", "TimeSpan");
        }
        static d(a) {
            TimeAxisBreakDescriptionMetadata.b(a);
            a.ad("TimeAxisBreak", () => new TimeAxisBreakDescription());
            a.ac("TimeAxisBreak", TimeAxisBreakDescriptionMetadata.a);
        }
    }
    TimeAxisBreakDescriptionMetadata.$t = /*@__PURE__*/ markType(TimeAxisBreakDescriptionMetadata, 'TimeAxisBreakDescriptionMetadata');
    TimeAxisBreakDescriptionMetadata.a = null;
    return TimeAxisBreakDescriptionMetadata;
})();

==> igniteui-react-core-18.7.5-beta.2.tgz: package/esm2015/lib/TimeAxisBreakDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { TimeAxisBreakDescription } from "./TimeAxisBreakDescription";
/**
 * @hidden
 */
export let TimeAxisBreakDescriptionMetadata = /*@__PURE__*/ (() => {
    class TimeAxisBreakDescriptionMetadata extends Base {
        static b(a) {
            if (TimeAxisBreakDescriptionMetadata.a == null) {
                TimeAxisBreakDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                TimeAxisBreakDescriptionMetadata.c(TimeAxisBreakDescriptionMetadata.a);
            }
            if (a.k(TimeAxisBreakDescriptionMetadata.a)) {
                return;
            }
            a.ac(TimeAxisBreakDescriptionMetadata.a);
        }
        static c(a) {
            a.item("Start", "Date");
            a.item("End", "Date");
            a.item("Interval", "TimeSpan");
        }
        static d(a) {
            TimeAxisBreakDescriptionMetadata.b(a);
            a.ae("TimeAxisBreak", () => new TimeAxisBreakDescription());
            a.ad("TimeAxisBreak", TimeAxisBreakDescriptionMetadata.a);
        }
    }
    TimeAxisBreakDescriptionMetadata.$t = /*@__PURE__*/ markType(TimeAxisBreakDescriptionMetadata, 'TimeAxisBreakDescriptionMetadata');
    TimeAxisBreakDescriptionMetadata.a = null;
    return TimeAxisBreakDescriptionMetadata;
})();
